@@ -1,9 +1,11 @@
 use tempfile::TempDir;
 
 use super::InteractiveChecker;
-use skyspell_core::tests::{FakeDictionary, FakeInteractor, FakeRepository};
+use skyspell_core::tests::{FakeDictionary, FakeRepository};
 use skyspell_core::{Checker, ProjectPath, RelativePath, Repository};
 
+use crate::tests::FakeInteractor;
+
 type TestChecker = InteractiveChecker<FakeInteractor, FakeDictionary, FakeRepository>;
 
 struct TestApp {
