@@ -3,18 +3,20 @@ use std::path::PathBuf;
 use anyhow::{bail, Context, Result};
 use clap::Parser;
 use colored::*;
-use ignore::WalkBuilder;
 
+use skyspell_core::ignore_file::walk;
 use skyspell_core::repository::RepositoryHandler;
 use skyspell_core::Checker;
 use skyspell_core::EnchantDictionary;
 use skyspell_core::TokenProcessor;
 use skyspell_core::{get_default_db_path, SQLRepository};
-use skyspell_core::{ConsoleInteractor, Dictionary, Repository};
+use skyspell_core::{Dictionary, Repository};
 use skyspell_core::{ProjectPath, RelativePath};
 
 mod checkers;
+pub mod interactor;
 pub use checkers::{InteractiveChecker, NonInteractiveChecker};
+pub use interactor::{ConsoleInteractor, Interactor};
 
 #[macro_export]
 macro_rules! info_1 {
@@ -234,10 +236,7 @@ where
     C: Checker<Context = (usize, usize)>,
 {
     let project = checker.project();
-    let walker = WalkBuilder::new(project.path().as_ref())
-        .add_custom_ignore_filename(".skyspell-ignore")
-        .build();
-
+    let walker = walk(project);
     let mut checked = 0;
     for dir_entry in walker {
         let dir_entry = dir_entry?;
