@@ -11,30 +11,30 @@ enum Answer {
 }
 
 #[derive(Debug, Default)]
-pub(crate) struct FakeInteractor {
+pub struct FakeInteractor {
     answers: RefCell<VecDeque<Answer>>,
 }
 
 impl FakeInteractor {
-    pub(crate) fn new() -> Self {
+    pub fn new() -> Self {
         Default::default()
     }
 
-    pub(crate) fn push_text(&self, text: &str) {
+    pub fn push_text(&self, text: &str) {
         self.answers
             .borrow_mut()
             .push_front(Answer::Text(text.to_string()))
     }
 
-    pub(crate) fn push_int(&self, i: usize) {
+    pub fn push_int(&self, i: usize) {
         self.answers.borrow_mut().push_front(Answer::Int(Some(i)))
     }
 
-    pub(crate) fn push_bool(&self, b: bool) {
+    pub fn push_bool(&self, b: bool) {
         self.answers.borrow_mut().push_front(Answer::Bool(b))
     }
 
-    pub(crate) fn is_empty(&self) -> bool {
+    pub fn is_empty(&self) -> bool {
         self.answers.borrow().is_empty()
     }
 }
